import React, {Component} from 'react'
import PropTypes from 'prop-types'
import { Form, Row, Col, Input, Radio, Tooltip } from 'antd'
import { QuestionCircleOutlined } from '@ant-design/icons'

import asyncComponent from '@/utils/asyncComponent'
import { formRule } from '@/utils/option.js'
import './index.scss'

const ColorSketch = asyncComponent(() => import('@/mob/colorsketch'))

class SettingForm extends Component {
  static propTpyes = {
    config: PropTypes.object,   // 表单配置信息
    inputSubmit: PropTypes.any  // 回车提交事件
  }

  state = {
    // roleList: [],
    type: this.props.config.setting.type || 'title'
  }

  UNSAFE_componentWillMount() {
    // let roleList = sessionStorage.getItem('sysRoles')
    // if (roleList) {
    //   try {
    //     roleList = JSON.parse(roleList)
    //   } catch (e) {
    //     roleList = []
    //   }
    // } else {
    //   roleList = []
    // }

    // this.setState({roleList})
  }

  handleConfirm = () => {
    // 表单提交时检查输入值是否正确
    return new Promise((resolve, reject) => {
      this.props.form.validateFieldsAndScroll((err, values) => {
        if (!err) {
          resolve(values)
        } else {
          reject(err)
        }
      })
    })
  }

  handleSubmit = (e) => {
    e.preventDefault()

    if (this.props.inputSubmit) {
      this.props.inputSubmit()
    }
  }

  render() {
    const { config } = this.props
    const { getFieldDecorator } = this.props.form
    const { type } = this.state

    const formItemLayout = {
      labelCol: {
        xs: { span: 24 },
        sm: { span: 8 }
      },
      wrapperCol: {
        xs: { span: 24 },
        sm: { span: 16 }
      }
    }

    return (
      <Form {...formItemLayout} className="mob-search-setting-form">
        <Row gutter={24}>
          <Col span={12}>
            <Form.Item label="顶部样式">
              {getFieldDecorator('type', {
                initialValue: type
              })(
                <Radio.Group style={{whiteSpace: 'nowrap'}} onChange={(e) => this.setState({type: e.target.value})}>
                  <Radio value="title">标题栏</Radio>
                  <Radio value="search">搜索栏</Radio>
                </Radio.Group>
              )}
            </Form.Item>
          </Col>
          <Col span={12}>
            <Form.Item label={
              <Tooltip placement="topLeft" title="使用搜索栏时，标题用于搜索条件隐藏时（当启用黑名单，登录用户无权限时）显示。">
                <QuestionCircleOutlined className="mk-form-tip" />
                标题
              </Tooltip>
            }>
              {getFieldDecorator('title', {
                initialValue: config.setting.title,
                rules: [
                  {
                    max: formRule.input.max,
                    message: formRule.input.message
                  }
                ]
              })(<Input placeholder="" autoComplete="off" onPressEnter={this.handleSubmit} />)}
            </Form.Item>
          </Col>
          {type === 'search' ? <Col span={12}>
            <Form.Item label="搜索字段">
              {getFieldDecorator('field', {
                initialValue: config.setting.field,
                rules: [
                  {
                    required: true,
                    message: '请填写字段!'
                  },
                  {
                    max: formRule.input.max,
                    message: formRule.input.message
                  },
                  {
                    pattern: formRule.field.multipattern,
                    message: formRule.field.message
                  }
                ]
              })(<Input placeholder="" autoComplete="off" onPressEnter={this.handleSubmit} />)}
            </Form.Item>
          </Col> : null}
          {type === 'search' ? <Col span={12}>
            <Form.Item label="初始值">
              {getFieldDecorator('initval', {
                initialValue: config.setting.initval,
                rules: [
                  {
                    max: formRule.input.max,
                    message: formRule.input.message
                  }
                ]
              })(<Input placeholder="" autoComplete="off" onPressEnter={this.handleSubmit} />)}
            </Form.Item>
          </Col> : null}
          {type === 'search' ? <Col span={12}>
            <Form.Item label="提示文字">
              {getFieldDecorator('label', {
                initialValue: config.setting.label,
                rules: [
                  {
                    max: formRule.input.max,
                    message: formRule.input.message
                  }
                ]
              })(<Input placeholder="" autoComplete="off" onPressEnter={this.handleSubmit} />)}
            </Form.Item>
          </Col> : null}
          {type === 'search' ? <Col span={12}>
            <Form.Item label="匹配方式">
              {getFieldDecorator('match', {
                initialValue: config.setting.match || 'like'
              })(
                <Radio.Group>
                  <Radio value="like">like</Radio>
                  <Radio value="not like">not like</Radio>
                  <Radio value="=">=</Radio>
                </Radio.Group>
              )}
            </Form.Item>
          </Col> : null}
          {type === 'search' ? <Col span={12}>
            <Form.Item label="必填">
              {getFieldDecorator('required', {
                initialValue: config.setting.required || 'false'
              })(
                <Radio.Group>
                  <Radio value="true">是</Radio>
                  <Radio value="false">否</Radio>
                </Radio.Group>
              )}
            </Form.Item>
          </Col> : null}
          {type === 'search' ? <Col span={12}>
            <Form.Item label="隐藏">
              {getFieldDecorator('Hide', {
                initialValue: config.setting.Hide || 'false'
              })(
                <Radio.Group>
                  <Radio value="true">是</Radio>
                  <Radio value="false">否</Radio>
                </Radio.Group>
              )}
            </Form.Item>
          </Col> : null}
          {type === 'search' ? <Col span={12}>
            <Form.Item label="自动聚焦">
              {getFieldDecorator('focus', {
                initialValue: config.setting.focus || 'true'
              })(
                <Radio.Group>
                  <Radio value="true">是</Radio>
                  <Radio value="false">否</Radio>
                </Radio.Group>
              )}
            </Form.Item>
          </Col> : null}
          <Col span={12}>
            <Form.Item label="搜索按钮">
              {getFieldDecorator('btn', {
                initialValue: config.setting.btn || 'hidden'
              })(
                <Radio.Group>
                  <Radio value="hidden">隐藏</Radio>
                  <Radio value="show">显示</Radio>
                </Radio.Group>
              )}
            </Form.Item>
          </Col>
          {type === 'search' && config.floor === 1 ? <Col span={12}>
            <Form.Item label="扫码">
              {getFieldDecorator('scan', {
                initialValue: config.setting.scan || 'false'
              })(
                <Radio.Group>
                  <Radio value="true">开启</Radio>
                  <Radio value="false">关闭</Radio>
                </Radio.Group>
              )}
            </Form.Item>
          </Col> : null}
          <Col span={12}>
            <Form.Item className="sys-bgcolor" label="背景色">
              {getFieldDecorator('backgroundColor', {
                initialValue: config.setting.backgroundColor || '#ffffff'
              })(
                <ColorSketch/>
              )}
            </Form.Item>
          </Col>
          {/* 去除移动端字段权限 */}
          {/* {type === 'search' ? <Col span={12}>
            <Form.Item label="黑名单">
              {getFieldDecorator('blacklist', {
                initialValue: config.setting.blacklist || []
              })(
                <Select
                  showSearch
                  mode="multiple"
                  filterOption={(input, option) => option.props.children.toLowerCase().indexOf(input.toLowerCase()) >= 0}
                >
                  {roleList.map(option =>
                    <Select.Option key={option.uuid} value={option.value}>{option.text}</Select.Option>
                  )}
                </Select>
              )}
            </Form.Item>
          </Col> : null} */}
        </Row>
      </Form>
    )
  }
}

export default Form.create()(SettingForm)